@@ -22,6 +22,8 @@ test_that("format of resultant data frame is as expected", {
 
 test_that("column means are calculated as expected", {
   skip_on_cran()
+  skip_on_ci()
+  skip_on_covr()
   skip_on_os("windows")
   suppressWarnings(expect_setequal(
     round(errorstats_mean_se$y,3),
@@ -31,6 +33,8 @@ test_that("column means are calculated as expected", {
 
 test_that("column medians are calculated as expected", {
   skip_on_cran()
+  skip_on_ci()
+  skip_on_covr()
   skip_on_os("windows")
   suppressWarnings(expect_setequal(
     round(errorstats_median_iqr$y,3),
